/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify Index - IndexSettingIndexMetadataService.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.solidify.service;

import java.util.List;

import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.stereotype.Service;

import ch.unige.solidify.controller.IndexController;
import ch.unige.solidify.index.indexing.IndexingService;
import ch.unige.solidify.model.index.IndexMetadata;
import ch.unige.solidify.model.index.IndexSettings;

@Service
@ConditionalOnBean(IndexController.class)
public class IndexSettingIndexMetadataService extends IndexResourceService<IndexSettings, IndexMetadata> {

  private IndexingService<IndexMetadata> indexingService;

  public IndexSettingIndexMetadataService(IndexingService<IndexMetadata> indexingService) {
    this.indexingService = indexingService;
  }

  @Override
  public IndexMetadata findOne(IndexSettings indexSettings, String id) {
    return this.indexingService.findOne(this.getIndexName(indexSettings), id);
  }

  @Override
  public List<IndexMetadata> findAll(IndexSettings indexSettings, IndexMetadata search) {
    return this.indexingService.findAll(this.getIndexName(indexSettings), search);
  }

  @Override
  public IndexMetadata save(IndexSettings indexSettings, IndexMetadata indexMetadata) {
    return this.indexingService.save(this.getIndexName(indexSettings), indexMetadata);
  }

  @Override
  public IndexMetadata update(IndexSettings indexSettings, IndexMetadata indexMetadata) {
    indexMetadata.setIndex(this.getIndexName(indexSettings));
    return this.indexingService.update(this.getIndexName(indexSettings), indexMetadata);
  }

  @Override
  public boolean delete(IndexSettings indexSettings, IndexMetadata indexMetadata) {
    indexMetadata.setIndex(this.getIndexName(indexSettings));
    return this.indexingService.delete(this.getIndexName(indexSettings), indexMetadata);
  }

  @Override
  public void deleteList(IndexSettings indexSettings, List<String> ids) {
    this.indexingService.deleteList(this.getIndexName(indexSettings), ids);
  }

  @Override
  public String getIndexName(IndexSettings indexSettings) {
    return indexSettings.getResId();
  }

}
