/*-
 * %%----------------------------------------------------------------------------------------------
 * Solidify Framework - Solidify Model - CreatedChangeInfo.java
 * SPDX-License-Identifier: GPL-2.0-or-later
 * %----------------------------------------------------------------------------------------------%
 * Copyright (C) 2017 - 2022 University of Geneva
 * %----------------------------------------------------------------------------------------------%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * ----------------------------------------------------------------------------------------------%%
 */

package ch.unige.solidify.model;

import java.io.Serializable;
import java.time.OffsetDateTime;
import javax.persistence.Embeddable;
import javax.persistence.Transient;

import org.springframework.data.annotation.CreatedDate;

import com.fasterxml.jackson.annotation.JsonFormat;

import ch.unige.solidify.util.StringTool;

@Embeddable
public class CreatedChangeInfo implements ChangeInfo, Serializable {

  private static final long serialVersionUID = -720221361236444701L;

  @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = StringTool.DATE_TIME_FORMAT)
  @CreatedDate
  private OffsetDateTime when;

  private String who;

  @Transient
  private String fullName;

  public OffsetDateTime getWhen() {
    return this.when;
  }

  public String getWho() {
    return this.who;
  }

  public void setWhen(OffsetDateTime when) {
    this.when = when;
  }

  public void setWho(String who) {
    this.who = who;
  }

  public String getFullName() {
    if (StringTool.isNullOrEmpty(this.fullName)) {
      return this.getWho();
    } else {
      return this.fullName;
    }
  }

  public void setFullName(String fullName) {
    this.fullName = fullName;
  }

  @Override
  public String toString() {
    return "CreateChangeInfo{" +
            "when=" + this.when +
            ", who='" + this.who + '\'' +
            '}';
  }

}
